@@ -2,7 +2,29 @@ package App::gh;
 use warnings;
 use strict;
 
-our $VERSION = '0.254';
+our $VERSION = '0.255';
+
+
+
+# XXX: move to othere place
+use App::gh::Utils;
+sub get_networks {
+    my $class = shift;
+    my $config = parse_config( ".git/config" );
+
+    my ( $name , $url ) = split( /\s+/ , qx( git remote -v | grep origin | grep push ) );
+
+    # git://github.com/miyagawa/Tatsumaki.git
+    if ( $url && ( $url =~ m{git://github.com/(.*?)/(.*?).git} 
+            || $url =~ m{git\@github.com:(.*?)/(.*?).git} ) ) {
+
+        my ($acc,$repo) = ($1,$2);
+        my $objs = api_request(qq(repos/show/$acc/$repo/network));
+        return $objs->{network};
+    }
+}
+
+
 
 __END__
 
